<?php
// $Id: flatmenu.admin.inc,v 1.1 2010/11/02 14:31:41 razorraser Exp $

/**
 * Menu callback for the path admin/build/flatmenu
 */
function flatmenu_overview() {
  $output = '';
  $items = variable_get('flatmenu_items', array());
  if (empty($items)) {
      $output .= '<div>' . t('There are no flat menus') . '</div>';
      $output .= l(t('Add a new flat menu'), 'admin/build/flatmenu/add');
  }
  else{
    $header = array(t('Name'), t('Menus'), t('Operations'));
    $rows = array();
    foreach($items as $key => $item) {
      $operations = array();
      $operations[] = l(t('Edit'), "admin/build/flatmenu/edit/$key");
      $operations[] = l(t('Delete'), "admin/build/flatmenu/delete/$key/confirm");
      $rows[] = array($item['itemname'], theme('item_list', $item['itemmenus']), theme('item_list', $operations));
    }
    $output .= theme('table', $header, $rows);
  }
  return $output;
}

/**
 * Menu callback for the path admin/build/flatmenu/add
 */
function flatmenu_add_item() {
  $output = '';
  $output .= drupal_get_form('flatmenu_form');
  return $output;
}

/**
 * Menu callback for the path admin/build/flatmenu/%/edit
 *
 * @param int $item a flat menu item number
 */
function flatmenu_edit_item($item) {
  $output = '';
  $output .= drupal_get_form('flatmenu_form', $item);
  return $output;
}

/**
 * Build the add/edit form.
 *
 * @param array $form_state
 * @param string $item
 *
 * @return array $form
 */
function flatmenu_form(&$form_state, $item = 0) {
  $items = variable_get('flatmenu_items', array());
  $form = array();
  $name = isset($items[$item]) ? $items[$item]['itemname'] : '';
  if ($name) {
    drupal_set_title(t("Edit '%name' flat menu", array('%name' => $name)));
  }
  else{
    drupal_set_title(t('Add a flat menu'));
  }
  $form['itemname'] = array(
    '#type' => 'textfield',
    '#title' => t('Block description'),
  	'#default_value' => $name,
  	'#required' => TRUE,
  	'#maxlength' => 64,
    '#description' => t('A brief description of your block. Used on the <a href="@overview">block overview page</a>.', array('@overview' => url('admin/build/block'))),
  );
  $form['itemmenus'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Menus'),
  	'#options' => menu_get_menus(TRUE),
  	'#default_value' => isset($items[$item]) ? $items[$item]['itemmenus'] : '',
  	'#required' => TRUE,
  );
  $form['flatmenuitem'] = array(
    '#type' => 'value',
    '#value' => $item,
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );
  return $form;
}

/**
 * Submit handler the add/edit form.
 *
 * @param array $form
 * @param array $form_state
 *
 */
function flatmenu_form_submit($form, &$form_state) {
  $items = variable_get('flatmenu_items', array());
  $item = $form_state['values']['flatmenuitem'];
  $values = array(
    'itemname' => $form_state['values']['itemname'],
    'itemmenus' => array_filter($form_state['values']['itemmenus']),
  );
  // A new flatmenu item
  if(!isset($items[$item])) {
    $items['flatmenu-item-'.(count($items)+1)] = $values;
  }
  else{
    $items[$item] = $values;
  }
  variable_set('flatmenu_items', $items);
  $form_state['redirect'] = 'admin/build/flatmenu';
}

/**
 * Confirmation page to delete a flatmenu item.
 *
 * @param string $item
 *
 * @return NULL | string $form
 */
function flatmenu_delete_item_confirm_page($item) {
  $items = variable_get('flatmenu_items', array());
  if (!isset($items[$item])) {
    drupal_access_denied();
    return NULL;
  }
  return drupal_get_form('flatmenu_delete_item_confirm_form', $item, $items[$item]['itemname']);
}

/**
 * Confirmation form to delete a flatmenu item.
 *
 * @param array $form_state
 * @param array $item
 * @param string $itemname
 */
function flatmenu_delete_item_confirm_form($form_state, $item, $itemname) {
  $form['itemid'] = array(
    '#type' => 'hidden',
    '#value' => $item,
  );
  $form['itemname'] = array(
    '#type' => 'hidden',
    '#value' => $itemname,
  );
  $caption .= '<p>'. t('This action cannot be undone.') .'</p>';
  return confirm_form($form, t('Are you sure you want to delete the flat menu %title?', array('%title' => $itemname)), 'admin/build/flatmenu', $caption, t('Delete'));
}

/**
 * Delete a flatmenu item.
 *
 * @param array $form
 * @param array $form_state
 */
function flatmenu_delete_item_confirm_form_submit($form, &$form_state) {
  $items = variable_get('flatmenu_items', array());
  unset($items[$form_state['values']['itemid']]);
  variable_set('flatmenu_items', $items);
  drupal_set_message(t('Deleted flat menu %name.', array('%name' => $form_state['values']['itemname'])));
  $form_state['redirect'] = 'admin/build/flatmenu';
  return;
}

