<?php
// $Id: flatmenu.items.inc,v 1.1 2010/11/02 14:31:41 razorraser Exp $

/**
 * Build the flatmenu array.
 *
 * @param array $item
 * @param string $delta
 *
 * @return array $flatmenu
 */
function _flatmenu_build_flatmenu($item, $delta) {
  $flatmenu = array();
  $front = drupal_is_front_page();
  foreach($item['itemmenus'] as $key => $menu) {
    // let a custom module provide the flatmenu
    drupal_alter('build_flatmenu_pre', $flatmenu, $menu, $delta, $front);
    if (empty($flatmenu[$key])) {
     $flatmenu[$key] =  _flatmenu_get_menulinks($menu, $front);
    }
    // let a custom module change a path, remove a path or whatever
    drupal_alter('build_flatmenu_post', $flatmenu, $menu, $delta, $front);
    if (empty($flatmenu[$key])) {
      unset($flatmenu[$key]);
    }
  }
  return $flatmenu;
}

/**
 * Collect the menu links for a menu.
 *
 * @param string $menu
 * @param bool $front
 *
 * @return array $links
 */
function _flatmenu_get_menulinks($menu, $front) {
  $links = $parents = array();
  if ($front) {
    // On frontpage we know the parents mlid (0)
    $parents = _flatmenu_get_menuitems($menu, $front);
  }
  else {
  	// on a subpage we need to know the mlid from the current page
  	// to know the parents
    $current = _flatmenu_get_menuitems($menu, FALSE);
    if (isset($current[0])) {
      $parents = _flatmenu_get_menuitems($menu, FALSE, $current[0]['object']->mlid);
    }
  }
  if (!empty($parents)) {
    foreach($parents as $key => $parent) {
      $links[$key]['parent'] = $parent;
      if ($parent['object']->has_children) {
        $links[$key]['children'] = _flatmenu_get_menuitems($menu, FALSE, $parent['object']->mlid);
      }
    }
  }
  return $links;
}

/**
 *
 *
 * @param string $menu
 * @param bool $front
 * @param int $mlid The id from a menu link.
 *
 * @return array $items A array of menu items with the keys title, path, options, object
 */
function _flatmenu_get_menuitems($menu, $front, $mlid = NULL) {
	global $language;
  $items = $params = array();
  if (!$mlid && !$front) {
    $params = array($menu, $_GET['q']);
    $SQL = 'SELECT * FROM {menu_links} WHERE menu_name = "%s" AND link_path = "%s"';
  }
  else{
    if ($front) {
      $mlid = 0;
    }
    $SQL = 'SELECT * FROM {menu_links} WHERE menu_name = "%s" AND plid = %d ORDER BY weight';
    $params = array($menu, $mlid);
  }
  $query = db_query($SQL, $params);
  while ($result = db_fetch_object($query)) {
    if ($result->hidden) {
      continue;
    }
    $options = unserialize($result->options);
    if ((empty($options) || !isset($options['langcode'])) || (isset($options['langcode']) && $options['langcode'] == $language->language)) {
      $items[] = array('title' => $result->link_title, 'path' => $result->link_path, 'options' => $options, 'object' => $result);
    }
  }
  return $items;
}

